diff --git a/ignite-html-input.js b/ignite-html-input.js
index b1ce5ee..898090b 100644
--- a/ignite-html-input.js
+++ b/ignite-html-input.js
@@ -60,11 +60,12 @@ IgniteTemplate.prototype.inputNumber = function(max = -1) {
/**
* Forces an input to only allow letters for input.
* @param {Number} max Max number of letters allow to be inputed. Default is -1 which disables this feature.
* @param {Boolean} allowSpace Whether or not to allow spaces to be entered. Default is true.
* @returns {IgniteTemplate} This ignite template.
*/
- IgniteTemplate.prototype.inputLetters = function(max = -1, allowSpace = true) {
+ IgniteTemplate.prototype.inputLetters = function(max = -1, allowSpaces = true, maxSpaces = -1) {
this.on("keydown", e => {
//If the input key isn't a letter, and it's not a space, backspace or escape or tab, ignore it.
if ((e.key < 'a' || e.key > 'z') && (e.key < 'A' || e.key > 'Z') && e.key != ' ' && e.key != 'Backspace' && e.key != 'Escape' && e.key != 'Tab' && e.key != 'Control' && e.ctrlKey == false) {
@@ -82,8 +83,8 @@ IgniteTemplate.prototype.inputNumber = function(max = -1) {
e.preventDefault();
return false;
}
- //If the key is space and space is not allowed prevent it.
- else if (allowSpace == false && e.key == ' ') {
+ //If the key is space and space is not allowed prevent it, or if it's allowed and we have too many spaces prevent it.
+ else if ((!allowSpaces && e.key == ' ') || (allowSpaces && e.key == ' ' && maxSpaces != -1 && e.target.value.split(' ').length > maxSpaces)) {
e.preventDefault();
return false;
}
@@ -60,11 +60,12 @@ IgniteTemplate.prototype.inputNumber = function(max = -1) {
/**
* Forces an input to only allow letters for input.
- * @param {Number} max Max number of letters allow to be inputed. Default is -1 which disables this feature.
- * @param {Boolean} allowSpace Whether or not to allow spaces to be entered. Default is true.
+ * @param {Number} max Max number of letters allowed to be inputed. Default is -1 which disables this feature.
+ * @param {Boolean} allowSpaces Whether or not to allow spaces to be entered. Default is true.
+ * @param {Number} maxSpaces Max number of spaces allowed tp be inputed. Default is -1 which disables this feature. This only works if allowSpaces is true.
* @returns {IgniteTemplate} This ignite template.
*/